@@ -3,11 +3,12 @@ from PythUnity.Classes import String
 from PythUnity.Functions import AddPrefab
 from PythUnity.Functions import GetPrefab
 from PythUnity.Functions import PrintFonts
-from PythUnity.Variables import *
 from PythUnity.main import init
 from PythUnity.help import help
+import PythUnity.Variables
 from pygame import Rect
 from pygame import image
 from pygame import Surface
 from pygame import font
-
+v = Variables.var
+del Variables
\ No newline at end of file
